@@ -17,7 +17,7 @@
 
 static int pound_arg, equal_arg;
 
-int pop2_ok (int sock, char *argbuf)
+static int pop2_ok (int sock, char *argbuf)
 /* parse POP2 command response */
 {
     int ok;
@@ -51,12 +51,17 @@ int pop2_ok (int sock, char *argbuf)
     return(ok);
 }
 
-int pop2_getauth(int sock, struct query *ctl, char *buf)
+static int pop2_getauth(int sock, struct query *ctl, char *buf)
 /* apply for connection authorization */
 {
-    return(gen_transact(sock,
+    int status;
+
+    strcpy(shroud, ctl->password);
+    status = gen_transact(sock,
 		  "HELO %s %s",
-		  ctl->remotename, ctl->password));
+		  ctl->remotename, ctl->password);
+    shroud[0] = '\0';
+    return status;
 }
 
 static int pop2_getrange(int sock, struct query *ctl, const char *folder, 
@@ -134,15 +139,16 @@ const static struct method pop2 =
     FALSE,				/* this is not a tagged protocol */
     FALSE,				/* does not use message delimiter */
     pop2_ok,				/* parse command response */
-    NULL,				/* no password canonicalization */
     pop2_getauth,			/* get authorization */
     pop2_getrange,			/* query range of messages */
     NULL,				/* no way to get sizes */
+    NULL,				/* no way to get sizes of subsets */
     NULL,				/* messages are always new */
     pop2_fetch,				/* request given message */
     NULL,				/* no way to fetch body alone */
     pop2_trail,				/* eat message trailer */
     NULL,				/* no POP2 delete method */
+    NULL,				/* how to mark a message as seen */
     pop2_logout,			/* log out, we're done */
     FALSE,				/* no, we can't re-poll */
 };
